using System;
using System.IO;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Reflection;

namespace EditorControl
{
	public class EditorImage : Image
	{
		private string resourceId = "";
		private string resourceUrl = "";

		public EditorImage(string id)
		{
			resourceId = id;
			resourceUrl = resourceId.Substring(resourceId.IndexOf(".") + 1);
			base.ImageUrl = "HtmlEditor" + Path.AltDirectorySeparatorChar + resourceUrl;
		}

		protected override void OnLoad(EventArgs e)
		{
			if (base.ImageUrl.IndexOf(resourceUrl) == -1) return; 
			Assembly asm = Assembly.GetExecutingAssembly();

			if (asm != null)
			{
				Stream stm = asm.GetManifestResourceStream(resourceId);
				
				if (stm == null) return;
				string folderPath = Page.Server.MapPath("HtmlEditor");
				string filePath = folderPath + Path.DirectorySeparatorChar + resourceUrl;

				if (!File.Exists(filePath))
				{
					System.Drawing.Image img = System.Drawing.Image.FromStream(stm);

					if (!Directory.Exists(folderPath))
						Directory.CreateDirectory(folderPath);

					img.Save(filePath, System.Drawing.Imaging.ImageFormat.Gif);
					img.Dispose();
				}
			}
		}

		protected override void AddAttributesToRender(HtmlTextWriter writer) 
		{
			writer.AddAttribute("onMouseOver", "ChangeImgLook(this,'over');");
			writer.AddAttribute("onMouseOut", "ChangeImgLook(this,'out');");
			writer.AddAttribute("onMouseDown", "ChangeImgLook(this,'down');");
			base.AddAttributesToRender(writer);
		}
	}
}
